Debugging Tips
========================================================================================

.. tip::
    If you're struggling with your dataset after looking over these tips, reach out!

    :doc:`/guide/contact`

Reduce step
-------------------------------------------------------------------------------

Errors like:

    ```
    Exception: "ArrowNotImplementedError('Unsupported cast from string to null using function cast_null')"
    ```